==> python-simpy_1.7.1.orig.tar.gz: SimPy-1.7.1/setup.py <==
#! /usr/bin/env python
from distutils.core import setup
setup(
      version="1.7.1",
      author="Tony Vignaux; Klaus Muller",
      author_email="vignaux@user.sourceforge.net;kgmuller@users.sourceforge.net",
      description="Version 1.7.1 of SimPy simulation package",
      long_description=\
"""Release 1.7.1 of SimPy is a minor release, fixing two bugs
in the _get methods of classes Store and Level and a bug in the
constructor of method of class Level. The 1.7.1 API is unchanged from 
that of 1.7.

SimPy is a process-based discrete-event simulation language
based on standard Python and released under the GNU LGPL. 

It provides the modeller with components of a simulation
model. These include processes, for active components like
customers, messages, and vehicles, and resources, for
passive components that form limited capacity congestion
points like servers, checkout counters, and tunnels. It
also provides monitor variables to aid in gathering
statistics. SimPy comes with extensive plotting capabilities.

The distribution contains in-depth documentation, tutorials,
and a large number of simulation models.

Simulation model developers are encouraged to share their
SimPy modeling techniques with the SimPy community. Please
post a message to the simpy-Users mailing list,

mailto:simpy-users@lists.sourceforge.net.

Subscribe to simpy-users mailing list:
http://lists.sourceforge.net/lists/listinfo/simpy-users

Software developers are also encouraged to interface SimPy with
other Python-accessible packages, such as GUI, data base or
mapping and to share these new capabilities with the
community under the GNU LGPL.
""",
      license="GNU LGPL",
      name="SimPy",
      url="simpy.sourceforge.net",
      packages=["SimPy"]
      )

==> python-simpy_1.8.orig.tar.gz: SimPy-1.8/setup.py <==
#! /usr/bin/env python
from distutils.core import setup
setup(
      version="1.8",
      author="Klaus Muller, Tony Vignaux",
      author_email="vignaux@user.sourceforge.net;kgmuller@users.sourceforge.net",
      description="Version 1.8 of SimPy simulation package",
      long_description=\
"""Release 1.8 of SimPy is a major release, with additions to
the API, new yield synchronization commands, and bug fixes.
Its documentation (Manual, Cheatsheet) have been totally overhauled.

SimPy is a process-based discrete-event simulation language
based on standard Python and released under the GNU LGPL. 

It provides the modeller with components of a simulation
model. These include processes, for active components like
customers, messages, and vehicles, and resources, for
passive components that form limited capacity congestion
points like servers, checkout counters, and tunnels. It
also provides monitor variables to aid in gathering
statistics. SimPy comes with extensive plotting capabilities.

The distribution contains in-depth documentation, tutorials,
and a large number of simulation models.

Simulation model developers are encouraged to share their
SimPy modeling techniques with the SimPy community. Please
post a message to the simpy-Users mailing list,

mailto:simpy-users@lists.sourceforge.net.

Subscribe to simpy-users mailing list:
http://lists.sourceforge.net/lists/listinfo/simpy-users

Software developers are also encouraged to interface SimPy with
other Python-accessible packages, such as GUI, data base or
mapping and to share these new capabilities with the
community under the GNU LGPL.
""",
      license="GNU LGPL",
      name="SimPy",
      url="simpy.sourceforge.net",
      packages=["SimPy"]
      )
